# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

import securefabric_pb2 as securefabric__pb2

GRPC_GENERATED_VERSION = "1.76.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(
        GRPC_VERSION, GRPC_GENERATED_VERSION
    )
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + " but the generated code in securefabric_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class FabricNodeStub(object):
    """FabricNode service provides secure messaging operations"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Send = channel.unary_unary(
            "/securefabric.FabricNode/Send",
            request_serializer=securefabric__pb2.SendReq.SerializeToString,
            response_deserializer=securefabric__pb2.SendResp.FromString,
            _registered_method=True,
        )
        self.Subscribe = channel.unary_stream(
            "/securefabric.FabricNode/Subscribe",
            request_serializer=securefabric__pb2.SubscribeReq.SerializeToString,
            response_deserializer=securefabric__pb2.Envelope.FromString,
            _registered_method=True,
        )
        self.Stats = channel.unary_unary(
            "/securefabric.FabricNode/Stats",
            request_serializer=securefabric__pb2.StatsReq.SerializeToString,
            response_deserializer=securefabric__pb2.StatsResp.FromString,
            _registered_method=True,
        )
        self.Join = channel.unary_unary(
            "/securefabric.FabricNode/Join",
            request_serializer=securefabric__pb2.NodeInfo.SerializeToString,
            response_deserializer=securefabric__pb2.JoinResp.FromString,
            _registered_method=True,
        )
        self.Unjoin = channel.unary_unary(
            "/securefabric.FabricNode/Unjoin",
            request_serializer=securefabric__pb2.NodeId.SerializeToString,
            response_deserializer=securefabric__pb2.JoinResp.FromString,
            _registered_method=True,
        )


class FabricNodeServicer(object):
    """FabricNode service provides secure messaging operations"""

    def Send(self, request, context):
        """Send a message to the fabric"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Subscribe(self, request, context):
        """Subscribe to messages on a topic"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Stats(self, request, context):
        """Get node statistics and metadata"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Join(self, request, context):
        """Join this node to another peer"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Unjoin(self, request, context):
        """Remove a peer from this node"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_FabricNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Send": grpc.unary_unary_rpc_method_handler(
            servicer.Send,
            request_deserializer=securefabric__pb2.SendReq.FromString,
            response_serializer=securefabric__pb2.SendResp.SerializeToString,
        ),
        "Subscribe": grpc.unary_stream_rpc_method_handler(
            servicer.Subscribe,
            request_deserializer=securefabric__pb2.SubscribeReq.FromString,
            response_serializer=securefabric__pb2.Envelope.SerializeToString,
        ),
        "Stats": grpc.unary_unary_rpc_method_handler(
            servicer.Stats,
            request_deserializer=securefabric__pb2.StatsReq.FromString,
            response_serializer=securefabric__pb2.StatsResp.SerializeToString,
        ),
        "Join": grpc.unary_unary_rpc_method_handler(
            servicer.Join,
            request_deserializer=securefabric__pb2.NodeInfo.FromString,
            response_serializer=securefabric__pb2.JoinResp.SerializeToString,
        ),
        "Unjoin": grpc.unary_unary_rpc_method_handler(
            servicer.Unjoin,
            request_deserializer=securefabric__pb2.NodeId.FromString,
            response_serializer=securefabric__pb2.JoinResp.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "securefabric.FabricNode", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "securefabric.FabricNode", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class FabricNode(object):
    """FabricNode service provides secure messaging operations"""

    @staticmethod
    def Send(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/securefabric.FabricNode/Send",
            securefabric__pb2.SendReq.SerializeToString,
            securefabric__pb2.SendResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Subscribe(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/securefabric.FabricNode/Subscribe",
            securefabric__pb2.SubscribeReq.SerializeToString,
            securefabric__pb2.Envelope.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Stats(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/securefabric.FabricNode/Stats",
            securefabric__pb2.StatsReq.SerializeToString,
            securefabric__pb2.StatsResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Join(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/securefabric.FabricNode/Join",
            securefabric__pb2.NodeInfo.SerializeToString,
            securefabric__pb2.JoinResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Unjoin(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/securefabric.FabricNode/Unjoin",
            securefabric__pb2.NodeId.SerializeToString,
            securefabric__pb2.JoinResp.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
