# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: securefabric.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "securefabric.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12securefabric.proto\x12\x0csecurefabric"\x95\x01\n\x08\x45nvelope\x12\x0e\n\x06pubkey\x18\x01 \x01(\x0c\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\x12\r\n\x05nonce\x18\x03 \x01(\x0c\x12\x0b\n\x03\x61\x61\x64\x18\x04 \x01(\x0c\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x0b\n\x03seq\x18\x06 \x01(\x04\x12\x0e\n\x06msg_id\x18\x07 \x01(\t\x12\x13\n\x0bkey_version\x18\x08 \x01(\r\x12\r\n\x05topic\x18\t \x01(\t"3\n\x07SendReq\x12(\n\x08\x65nvelope\x18\x01 \x01(\x0b\x32\x16.securefabric.Envelope"&\n\x08SendResp\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x0e\n\x06msg_id\x18\x02 \x01(\t"\x1d\n\x0cSubscribeReq\x12\r\n\x05topic\x18\x01 \x01(\x0c"\n\n\x08StatsReq"r\n\tStatsResp\x12\r\n\x05peers\x18\x01 \x01(\r\x12\x16\n\x0ep95_latency_ms\x18\x02 \x01(\x01\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0f\n\x07git_sha\x18\x04 \x01(\t\x12\r\n\x05\x62uilt\x18\x05 \x01(\t\x12\r\n\x05rustc\x18\x06 \x01(\t"9\n\x08NodeInfo\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\t\x12\x0e\n\x06pubkey\x18\x03 \x01(\x0c"\x16\n\x08JoinResp\x12\n\n\x02ok\x18\x01 \x01(\x08"\x19\n\x06NodeId\x12\x0f\n\x07node_id\x18\x01 \x01(\t2\xb0\x02\n\nFabricNode\x12\x35\n\x04Send\x12\x15.securefabric.SendReq\x1a\x16.securefabric.SendResp\x12\x41\n\tSubscribe\x12\x1a.securefabric.SubscribeReq\x1a\x16.securefabric.Envelope0\x01\x12\x38\n\x05Stats\x12\x16.securefabric.StatsReq\x1a\x17.securefabric.StatsResp\x12\x36\n\x04Join\x12\x16.securefabric.NodeInfo\x1a\x16.securefabric.JoinResp\x12\x36\n\x06Unjoin\x12\x14.securefabric.NodeId\x1a\x16.securefabric.JoinRespb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "securefabric_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_ENVELOPE"]._serialized_start = 37
    _globals["_ENVELOPE"]._serialized_end = 186
    _globals["_SENDREQ"]._serialized_start = 188
    _globals["_SENDREQ"]._serialized_end = 239
    _globals["_SENDRESP"]._serialized_start = 241
    _globals["_SENDRESP"]._serialized_end = 279
    _globals["_SUBSCRIBEREQ"]._serialized_start = 281
    _globals["_SUBSCRIBEREQ"]._serialized_end = 310
    _globals["_STATSREQ"]._serialized_start = 312
    _globals["_STATSREQ"]._serialized_end = 322
    _globals["_STATSRESP"]._serialized_start = 324
    _globals["_STATSRESP"]._serialized_end = 438
    _globals["_NODEINFO"]._serialized_start = 440
    _globals["_NODEINFO"]._serialized_end = 497
    _globals["_JOINRESP"]._serialized_start = 499
    _globals["_JOINRESP"]._serialized_end = 521
    _globals["_NODEID"]._serialized_start = 523
    _globals["_NODEID"]._serialized_end = 548
    _globals["_FABRICNODE"]._serialized_start = 551
    _globals["_FABRICNODE"]._serialized_end = 855
# @@protoc_insertion_point(module_scope)
